using System;
using CookComputing.XmlRpc;

namespace BlogSmart.Blog
{
	/// <summary>
	/// This is a class to handle dealing with the Blogger/MoveableType API
	/// </summary>
	
	public struct BlogData
	{
		public string title;
		public string description;	
		public string[] categories;
	}

	public struct MTPostConfirm
	{
		public string[] categories;
		public string postid;
	}

	public struct UserBlog
	{
		public string blogid;
		public string blogName;
		public string url;
	}

	public struct CategoryListing
	{
		public string categoryId;
		public string description;
		public string categoryName; 
		public string htmlUrl;
		public string rssUrl;
	}

	public struct RecentPostTitles
	{
		public DateTime dateCreated;
		public string userid;
		public string postid;
		public string title;
	}

	public struct UserInfo
	{
		public string userid;
		public string firstname;
		public string lastname;
		public string nickname;
		public string email;
		public string url;
	}

	public struct RecentPost
	{
		public DateTime dateCreated;
		public string userid;
		public string postid;
		public string content;
	}

	[XmlRpcUrl("http://192.168.0.100:8080/wordpress/xmlrpc.php")]
	public class BloggerAPI : XmlRpcClientProtocol
	{
		[XmlRpcMethod("blogger.newPost")]
		public string NewPost(
			string appkey,
			string blogid,
			string username,
			string password,
			string contents,
			bool publish)
		{
			return (string)Invoke("NewPost", new object[] {appkey, blogid, username, password, contents, publish});
		}

		/*[XmlRpcMethod("metaWeblog.newPost")]
		public string NewPost(			
			string blogid,
			string username,
			string password,
			BlogData BlogData,
			bool publish)
		{
			return (string)Invoke("NewPost", new object[] {blogid, username, password, BlogData, publish});
		}*/

		[XmlRpcMethod("mt.getCategoryList")]
		public CategoryListing[] GetCategoryList(			
			string blogid,
			string username,
			string password)
		{
			return (CategoryListing[])Invoke("GetCategoryList", new object[] {blogid, username, password});
		}

		[XmlRpcMethod("mt.getRecentPostTitles")]
		public RecentPostTitles[] GetRecentPostTitles(			
			string blogid,
			string username,
			string password,
			int numberOfPosts)
		{
			return (RecentPostTitles[])Invoke("GetRecentPostTitles", new object[] {blogid, username, password, numberOfPosts});
		}

		[XmlRpcMethod("metaWeblog.editPost")]
		public bool EditPost(			
			string postid,
			string username,
			string password,
			BlogData BlogData,
			bool publish)
		{
			return (bool)Invoke("EditPost", new object[] {postid, username, password, BlogData, publish});
		}


		/* [XmlRpcMethod("blogger.editPost")]
		public bool EditPost(
			string appkey,
			string postid,
			string username,
			string password,
			string contents,
			bool publish)
		{
			return (bool)Invoke("EditPost", new object[]{appkey, postid, username, password, contents, publish});
		}*/

		[XmlRpcMethod("blogger.getUsersBlogs")]
		public UserBlog[] GetUsersBlogs(
			string appkey,
			string username,
			string password)
		{
			return (UserBlog[])Invoke("GetUsersBlogs", new object[]{appkey, username, password});
		}

		[XmlRpcMethod("blogger.getUserInfo")]
		public UserInfo GetUserInfo(
			string appkey,
			string username,
			string password)
		{
			return (UserInfo)Invoke("GetUserInfo", new object[]{appkey, username, password});
		}

		[XmlRpcMethod("blogger.getTemplate")]
		public string GetTemplate(
			string appkey,
			string blogid,
			string username,
			string password,
			string templateType)
		{
			return (string)Invoke("GetTemplate", new object[]{appkey, blogid, username, password, templateType});
		}

		[XmlRpcMethod("blogger.setTemplate")]
		public string SetTemplate(
			string appkey,
			string blogid,
			string username,
			string password,
			string template,
			string templateType)
		{
			return (string)Invoke("SetTemplate", new object[]{appkey, blogid, username, password,template, templateType});
		}

		[XmlRpcMethod("blogger.getRecentPosts")]
		public RecentPost[] GetRecentPosts(
			string appkey,
			string blogid,
			string username,
			string password,
			int numberOfPosts)
		{
			return (RecentPost[])Invoke("GetRecentPosts", new object[]{appkey, blogid, username, password, numberOfPosts});}
		}
}
